| ConsumerPriceIndexUK | R Documentation |
The UK Office for National Statistics publishes updated Consumer Price Index data every month. There are 12 sectors with from 1 to 7 subsectors and the subsectors comprise up to 9 items.
data(CPIuk)
A data frame with 85 observations on the following 10 variables.
IDID number made up of Sector, Subsector, Item numbers
SectorIDSector number
SubsectorIDSubsector number within sector
ItemItem number within Sector
SectorSector label
SubsectorSubsector label
ComponentItem label
WeightItem weight in 2017
Aug2017Item index value in August 2017
Aug2018Item index value in August 2018
Office for National Statistics (ONS) UK
https://www.ons.gov.uk/economy/inflationandpriceindices/datasets/consumerpriceinflation/
yw <- ud_prep(CPIuk, weight="Weight", v1="Aug2017", v2="Aug2018",
levs=c("Sector"), sortLev=c("perc"))
y2 <- ud_plot(yw, labelvar="Sector")
y2$uadl
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.